"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _giSdk = require("@antv/gi-sdk");
var _antd = require("antd");
var _react = _interopRequireDefault(require("react"));
var _registerMeta = require("./registerMeta");
var _i18n = _interopRequireDefault(require("../i18n"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
var ResultTable = function ResultTable(_ref) {
  var _ref$matches = _ref.matches,
    matches = _ref$matches === void 0 ? [] : _ref$matches;
  var _useContext = (0, _giSdk.useContext)(),
    graph = _useContext.graph;
  var getResultColumns = function getResultColumns() {
    var columns = [{
      title: _i18n.default.get({
        id: 'gi-assets-algorithm.src.PatternMatch.resultTable.SerialNumber',
        dm: '序号'
      }),
      dataIndex: 'index',
      key: 'index',
      width: 60
    }, {
      title: _i18n.default.get({
        id: 'gi-assets-algorithm.src.PatternMatch.resultTable.NumberOfNodes',
        dm: '节点数量'
      }),
      dataIndex: 'nodeNum',
      key: 'nodeNum'
    }, {
      title: _i18n.default.get({
        id: 'gi-assets-algorithm.src.PatternMatch.resultTable.NumberOfEdges',
        dm: '边数量'
      }),
      dataIndex: 'edgeNum',
      key: 'edgeNum'
    }];
    return columns;
  };
  var getResultTableData = function getResultTableData() {
    return matches.map(function (match, i) {
      var _a, _b;
      return {
        key: "".concat(i),
        index: i + 1,
        nodeNum: ((_a = match.nodes) === null || _a === void 0 ? void 0 : _a.length) || 0,
        edgeNum: ((_b = match.edges) === null || _b === void 0 ? void 0 : _b.length) || 0
      };
    });
  };
  var clearActiveItems = function clearActiveItems() {
    var activateItems = graph.findAllByState('node', _registerMeta.ITEM_STATE.Active).concat(graph.findAllByState('edge', _registerMeta.ITEM_STATE.Active));
    activateItems.forEach(function (item) {
      graph.setItemState(item, _registerMeta.ITEM_STATE.Active, false);
    });
  };
  var onEnterTableRow = function onEnterTableRow(record) {
    var _a, _b, _c, _d;
    clearActiveItems();
    (_b = (_a = matches[record.index - 1]) === null || _a === void 0 ? void 0 : _a.nodes) === null || _b === void 0 ? void 0 : _b.forEach(function (node) {
      graph.setItemState(node.id, _registerMeta.ITEM_STATE.Active, true);
    });
    (_d = (_c = matches[record.index - 1]) === null || _c === void 0 ? void 0 : _c.edges) === null || _d === void 0 ? void 0 : _d.forEach(function (edge) {
      graph.setItemState(edge.id, _registerMeta.ITEM_STATE.Active, true);
    });
  };
  return /*#__PURE__*/_react.default.createElement("div", {
    className: "kg-pattern-match-result-wrapper"
  }, /*#__PURE__*/_react.default.createElement("p", {
    className: "kg-pattern-match-result-title"
  }, _i18n.default.get({
    id: 'gi-assets-algorithm.src.PatternMatch.resultTable.PatternMatchingResultList',
    dm: '模式匹配结果列表'
  })), /*#__PURE__*/_react.default.createElement(_antd.Table, {
    dataSource: getResultTableData(),
    columns: getResultColumns(),
    size: "small",
    style: {
      marginTop: '16px'
    },
    showSorterTooltip: {
      title: _i18n.default.get({
        id: 'gi-assets-algorithm.src.PatternMatch.resultTable.Sort',
        dm: '排序'
      })
    },
    onRow: function onRow(record) {
      return {
        onMouseEnter: function onMouseEnter() {
          return onEnterTableRow(record);
        },
        onMouseLeave: clearActiveItems
      };
    }
  }));
};
var _default = ResultTable;
exports.default = _default;